# StreamLinks


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_self** | [**StreamSelfLink**](StreamSelfLink.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.streaming.models.stream_links import StreamLinks

# TODO update the JSON string below
json = "{}"
# create an instance of StreamLinks from a JSON string
stream_links_instance = StreamLinks.from_json(json)
# print the JSON string representation of the object
print(StreamLinks.to_json())

# convert the object into a dict
stream_links_dict = stream_links_instance.to_dict()
# create an instance of StreamLinks from a dict
stream_links_from_dict = StreamLinks.from_dict(stream_links_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


